moodlesg package
================

Submodules
----------

moodlesg.moodlesg module
------------------------

.. automodule:: moodlesg.moodlesg
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: moodlesg
    :members:
    :undoc-members:
    :show-inheritance:
